@@ -1,19 +1,18 @@
 from __future__ import print_function, absolute_import
 from copy import deepcopy
+from collections import OrderedDict
 from fontMath.mathFunctions import (
     add, addPt, div, divPt, mul, mulPt, _roundNumber, sub, subPt)
 from fontMath.mathGuideline import (
     _compressGuideline, _expandGuideline, _pairGuidelines,
     _processMathOneGuidelines, _processMathTwoGuidelines, _roundGuidelines)
-from ufoLib.pointPen import AbstractPointPen
+from fontTools.pens.pointPen import AbstractPointPen
 
 # ------------------
 # UFO 3 branch notes
 # ------------------
 #
 # to do:
-# X anchors
-#   - try to preserve ordering?
 # X components
 #   X identifiers
 # X contours
@@ -288,7 +287,7 @@ class MathGlyph(object):
 
     def draw(self, pen, filterRedundantPoints=False):
         """draw self using pen"""
-        from ufoLib.pointPen import PointToSegmentPen
+        from fontTools.pens.pointPen import PointToSegmentPen
         pointPen = PointToSegmentPen(pen)
         self.drawPoints(pointPen, filterRedundantPoints=filterRedundantPoints)
 
@@ -523,7 +522,7 @@ def _processMathTwoContours(contours, factor, func):
 # anchors
 
 def _anchorTree(anchors):
-    tree = {}
+    tree = OrderedDict()
     for anchor in anchors:
         x = anchor["x"]
         y = anchor["y"]
